summaryrefslogtreecommitdiff
path: root/lang/python/python-zeroconf
diff options
context:
space:
mode:
authorRosen Penev <rosenp@gmail.com>2020-07-11 15:37:21 -0700
committerRosen Penev <rosenp@gmail.com>2020-07-11 23:25:48 -0700
commit0ef247cf5da5d04bff1a8ff993622a22b2fdca1f (patch)
treec9a3fad4c2719b6bfbc3cb3e151eb1cba8cc9a50 /lang/python/python-zeroconf
parent147a5f7e3122e33c8f64372f89fde8c3600313c2 (diff)
libvorbis: update to 1.3.7
Switched to CMake for the faster compilation and the simpler Makefile. Minor Makefile cleanups. Before: time make package/libvorbis/compile -j 12 Executed in 24.40 secs fish external usr time 21.17 secs 0.00 micros 21.17 secs sys time 3.05 secs 426.00 micros 3.05 secs After: time make package/libvorbis/compile -j 12 Executed in 9.19 secs fish external usr time 11.29 secs 0.00 micros 11.29 secs sys time 1.43 secs 421.00 micros 1.43 secs Signed-off-by: Rosen Penev <rosenp@gmail.com>
Diffstat (limited to 'lang/python/python-zeroconf')
0 files changed, 0 insertions, 0 deletions